@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006 Free Software Foundation
  *
  * Author: Nikos Mavroyanopoulos
  *
@@ -29,17 +29,31 @@
 
 #include <defines.h>
 
+#if 1
+
+#include <gnutls_int.h>
+
+/* The function below rely on some internal libtasn1 functions.  While
+   it would be easy to export them (or copy them) we prefer not to at
+   this point.  If you need the XML functionality, simply build with
+   --with-included-libtasn1 and change the '1' above to '0', or help
+   us add XML export functions to libtasn1 proper. */
+
+int
+gnutls_x509_crt_to_xml (gnutls_x509_crt_t cert, gnutls_datum_t * res,
+			int detail)
+{
+  return GNUTLS_E_INTERNAL_ERROR;
+}
+
+#else
+
 #ifdef ENABLE_PKI
 
 #include <int.h>
 #include <errors.h>
 #include <structure.h>
 #include <parser_aux.h>
-#include <der.h>
-#define LIBASN1_H		/* we use this since this file uses
-				 * libtasn1 internals, and we don't want the
-				 * exported API.
-				 */
 #include <gnutls_int.h>
 #include <gnutls_datum.h>
 #include <gnutls_global.h>
@@ -49,9 +63,6 @@
 #include <x509.h>
 #include <common.h>
 
-const char *asn1_find_structure_from_oid (ASN1_TYPE definitions,
-					  const char *oidValue);
-
 static int _gnutls_x509_expand_extensions (ASN1_TYPE * rasn);
 
 static const void *
@@ -379,7 +390,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
       if (p->type == TYPE_BIT_STRING)
 	{
 	  len2 = -1;
-	  len = _asn1_get_length_der (p->value, p->value_len, &len2);
+	  len = asn1_get_length_der (p->value, p->value_len, &len2);
 	  snprintf (tmp, sizeof (tmp), " length=\"%i\"",
 		    (len - 1) * 8 - (p->value[len2]));
 	  STR_APPEND (tmp);
@@ -412,7 +423,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 	      if (value)
 		{
 		  len2 = -1;
-		  len = _asn1_get_length_der (value, p->value_len, &len2);
+		  len = asn1_get_length_der (value, p->value_len, &len2);
 
 		  for (k = 0; k < len; k++)
 		    {
@@ -426,7 +437,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 	      if (value)
 		{
 		  len2 = -1;
-		  len = _asn1_get_length_der (value, p->value_len, &len2);
+		  len = asn1_get_length_der (value, p->value_len, &len2);
 
 		  for (k = 0; k < len; k++)
 		    {
@@ -456,7 +467,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 	      if (value)
 		{
 		  len2 = -1;
-		  len = _asn1_get_length_der (value, p->value_len, &len2);
+		  len = asn1_get_length_der (value, p->value_len, &len2);
 
 		  for (k = 1; k < len; k++)
 		    {
@@ -469,7 +480,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 	      if (value)
 		{
 		  len2 = -1;
-		  len = _asn1_get_length_der (value, p->value_len, &len2);
+		  len = asn1_get_length_der (value, p->value_len, &len2);
 		  for (k = 0; k < len; k++)
 		    {
 		      snprintf (tmp, sizeof (tmp), "%02X", (value)[k + len2]);
@@ -487,7 +498,7 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 		  if (value)
 		    {
 		      len3 = -1;
-		      len2 = _asn1_get_length_der (value, p->value_len, &len3);
+		      len2 = asn1_get_length_der (value, p->value_len, &len3);
 		      for (k = 0; k < len2; k++)
 			{
 			  snprintf (tmp, sizeof (tmp),
@@ -507,7 +518,8 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
 		    type_field (up->left->type) == TYPE_OBJECT_ID)
 		  {
 
-		    len2 = _asn1_get_length_der (up->value, up->value_len, &len3);
+		    len2 =
+		      asn1_get_length_der (up->value, up->value_len, &len3);
 
 		    if (len2 > 0 && strcmp (p->name, "type") == 0)
 		      {
@@ -666,8 +678,13 @@ _gnutls_asn1_get_structure_xml (ASN1_TYPE structure,
   * @res: The datum that will hold the result
   * @detail: The detail level (must be GNUTLS_XML_SHOW_ALL or GNUTLS_XML_NORMAL)
   *
-  * This function will return the XML structures of the given X.509 certificate.
-  * The XML structures are allocated internally (with malloc) and stored into res.
+  * This function will return the XML structures of the given X.509
+  * certificate.  The XML structures are allocated internally (with
+  * malloc) and stored into res.
+  *
+  * NOTE: This function is currently not implemented.  See the NEWS
+  * entry for version 1.3.5.
+  *
   * Returns a negative error code in case of an error.
   *
   **/
@@ -742,3 +759,4 @@ _gnutls_x509_expand_extensions (ASN1_TYPE * rasn)
 }
 
 #endif
+#endif
